@@ -3,7 +3,7 @@ package Text::Table::Any;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2021-02-16'; # DATE
 our $DIST = 'Text-Table-Any'; # DIST
-our $VERSION = '0.099'; # VERSION
+our $VERSION = '0.100'; # VERSION
 
 #IFUNBUILT
 # # use 5.010001;
@@ -36,6 +36,7 @@ our @BACKENDS = qw(
                       Text::Table::TSV
                       Text::Table::XLSX
                       Text::TabularDisplay
+                      Text::UnicodeBox::Table
               );
 
 sub _encode {
@@ -143,6 +144,17 @@ sub table {
             $t->data($rows);
         }
         return join("\n", @{$t->render(padding => 1)}) . "\n";
+    } elsif ($backend eq 'Text::UnicodeBox::Table') {
+        require Text::UnicodeBox::Table;
+        my $t = Text::UnicodeBox::Table->new;
+        if ($header_row) {
+            $t->add_header(@{ $rows->[0] });
+            $t->add_row(@{ $rows->[$_] }) for 1 .. $#{$rows};
+        } else {
+            $t->add_header(map {"col$_"} 0..$#{$rows->[0]});
+            $t->add_row(@{ $rows->[$_] }) for 0 .. $#{$rows};
+        }
+        return $t->render;
     } elsif ($backend eq 'Text::ASCIITable') {
         require Text::ASCIITable;
         my $t = Text::ASCIITable->new();
@@ -218,7 +230,7 @@ Text::Table::Any - Generate text table using one of several backends
 
 =head1 VERSION
 
-This document describes version 0.099 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2021-02-16.
+This document describes version 0.100 of Text::Table::Any (from Perl distribution Text-Table-Any), released on 2021-02-16.
 
 =head1 SYNOPSIS
 
@@ -396,6 +408,8 @@ Optional. Pick a backend module. Supported backends:
 
 =item * Text::TabularDisplay
 
+=item * Text::UnicodeBox::Table
+
 =back
 
 =item * header_row (bool, default 0)
